---
title: <span class="badge object-type-scalar"></span> MegabitsPerSecond
---
# <span class="badge object-type-scalar"></span> MegabitsPerSecond

Data rate: megabits/sec

## Definition

```python
# Data rate: megabits/sec
MegabitsPerSecond: typing.Literal["Mbits"] = "Mbits"
```
